2024-07-19 Version: 2.1.1
- Generated python 2024-03-13 for IntelligentCreation.

2024-07-19 Version: 2.1.0
- Support API AddTextFeedback.
- Support API CheckSession.
- Support API GetProjectTask.
- Support API GetTextTemplate.
- Support API ListAnchor.
- Support API ListVoiceModels.
- Support API QueryAvatarProject.
- Support API QueryAvatarResource.
- Support API SelectResource.
- Support API SendTextMsg.
- Support API StartAvatarSession.
- Support API StopAvatarSession.
- Support API StopProjectTask.
- Support API SubmitProjectTask.


2024-06-17 Version: 2.0.2
- Generated python 2024-03-13 for IntelligentCreation.

2024-06-13 Version: 2.0.1
- Generated python 2024-03-13 for IntelligentCreation.

2024-05-29 Version: 2.0.0
- Support API ListTexts.
- Update API ListTextThemes: add param industry.


2024-05-20 Version: 1.0.0
- Generated python 2024-03-13 for IntelligentCreation.

